@@ -13,13 +13,14 @@
 ellipse <- function(x, y, a, b, rotation = 0, gp = NULL) {
 
 	poly <- VennDiagram::ell2poly(x, y, a, b, rotation, 3000);
-
-	return(
-		polygonGrob(
+	
+	ret <- 	polygonGrob(
 			x = poly$x,
 			y = poly$y,
 			gp = gp
 			)
-		);
+	ret$params <- list(x=x, y=y, a=a, b=b, rotation=rotation);
+
+	return(ret);
 
 	}
